Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4491)

Unified Diff: chrome/browser/chromeos/login/login_performer.h

Issue 12704002: Support for auth code based authentication flow for both app and web UI driven flow. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase4 Created 7 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/chromeos/login/login_display.h ('k') | chrome/browser/chromeos/login/login_performer.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/chromeos/login/login_performer.h
diff --git a/chrome/browser/chromeos/login/login_performer.h b/chrome/browser/chromeos/login/login_performer.h
index 088b567e8a836bfc4d375c65f8fd3268373c4b38..973dba2e49ffc47145ee9bb09ca618d94d055b6f 100644
--- a/chrome/browser/chromeos/login/login_performer.h
+++ b/chrome/browser/chromeos/login/login_performer.h
@@ -12,6 +12,7 @@
#include "chrome/browser/chromeos/login/authenticator.h"
#include "chrome/browser/chromeos/login/login_status_consumer.h"
#include "chrome/browser/chromeos/login/online_attempt_host.h"
+#include "chrome/browser/chromeos/login/user.h"
#include "chrome/browser/profiles/profile_manager.h"
#include "content/public/browser/notification_observer.h"
#include "content/public/browser/notification_registrar.h"
@@ -84,18 +85,16 @@ class LoginPerformer : public LoginStatusConsumer,
virtual void OnLoginFailure(const LoginFailure& error) OVERRIDE;
virtual void OnRetailModeLoginSuccess() OVERRIDE;
virtual void OnLoginSuccess(
- const std::string& username,
- const std::string& password,
+ const UserCredentials& credentials,
bool pending_requests,
bool using_oauth) OVERRIDE;
virtual void OnOffTheRecordLoginSuccess() OVERRIDE;
virtual void OnPasswordChangeDetected() OVERRIDE;
- // Performs a login for |username| and |password|. If auth_mode is
- // AUTH_MODE_EXTENSION, there are no further auth checks, AUTH_MODE_INTERNAL
- // will perform auth checks.
- void PerformLogin(const std::string& username,
- const std::string& password,
+ // Performs a login for |credentials|.
+ // If auth_mode is AUTH_MODE_EXTENSION, there are no further auth checks,
+ // AUTH_MODE_INTERNAL will perform auth checks.
+ void PerformLogin(const UserCredentials& credentials,
AuthorizationMode auth_mode);
// Performs locally managed user creation and login.
@@ -104,8 +103,7 @@ class LoginPerformer : public LoginStatusConsumer,
// Performs locally managed user login with a given |username| and |password|.
// Managed user creation should be done with CreateLocallyManagedUser().
- void LoginAsLocallyManagedUser(const std::string& username,
- const std::string& password);
+ void LoginAsLocallyManagedUser(const UserCredentials& credentials);
// Performs retail mode login.
void LoginRetailMode();
@@ -198,9 +196,8 @@ class LoginPerformer : public LoginStatusConsumer,
// sign-in server. LoginFailure.LoginFailureNone() by default.
LoginFailure last_login_failure_;
- // Username and password for the current login attempt.
- std::string username_;
- std::string password_;
+ // User credentials for the current login attempt.
+ UserCredentials credentials_;
// Notifications receiver.
Delegate* delegate_;
« no previous file with comments | « chrome/browser/chromeos/login/login_display.h ('k') | chrome/browser/chromeos/login/login_performer.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698